@@ -452,7 +452,8 @@ public class CDF2CDFML implements CDFConstants {
                     // tag[1] - attribute entry tag name
 
                     String[] tags =  getAttributeAndEntryTagNames();
-Object newAttrName = GetMyCDFData.replaceStringNameToXML ((Object)attrName);
+                    Object newAttrName = GetMyCDFData.replaceStringNameToXML (
+                                                          (Object)attrName);
                     out.println ("<"+tags[0]+" name=\""+newAttrName+"\">");
                     indent++;
                     if (mode.equalsIgnoreCase("cdfxdf")) {
@@ -504,20 +505,19 @@ Object newAttrName = GetMyCDFData.replaceStringNameToXML ((Object)attrName);
                                  eDataType == CDF_UCHAR) {
                                Object data1 = 
                                       GetMyCDFData.replaceStringDataToXML(data);
-                                   CDFUtils.printData (data1,
-                                                       out, iflag, iso8601_x);
+                                   CDFUtils.printData (data1, out, iflag,
+                                                       iso8601_x);
                              } else {
                                if (iflag == 0 || !iso8601_x)
-                                   CDFUtils.printData (data,
-                                                       out, iflag, iso8601_x);
+                                   CDFUtils.printData (data, out, iflag,
+                                                       iso8601_x);
                                else {
                                  if (!withz)
-                                   CDFUtils.printData (data,
-                                                       out, iflag, iso8601_x);
+                                   CDFUtils.printData (data, out, iflag,
+                                                       iso8601_x);
                                  else
-                                   CDFUtils.printData (data,
-                                                       out, iflag, iso8601_x,
-                                                       "Z");
+                                   CDFUtils.printData (data, out, iflag,
+                                                       iso8601_x, "Z");
                                }
                              }
                            }
@@ -608,8 +608,8 @@ Object newAttrName = GetMyCDFData.replaceStringNameToXML ((Object)attrName);
                    }
 
                    outputIndentation(indent);
-Object newVarName = GetMyCDFData.replaceStringNameToXML ((Object)varName);
-out.println ("<variable name=\""+newVarName+"\">");
+                   Object newVarName = GetMyCDFData.replaceStringNameToXML ((Object)varName);
+                   out.println ("<variable name=\""+newVarName+"\">");
 /*
                    if (varName.indexOf("\"") < 0)
                      out.println ("<variable name=\""+varName+"\">");
@@ -804,7 +804,7 @@ out.println ("<variable name=\""+newVarName+"\">");
             for (Enumeration e=va.elements(); e.hasMoreElements();) {
                  a = (Attribute) e.nextElement();
                  attrName = a.getName();
-Object newAttrName = GetMyCDFData.replaceStringNameToXML ((Object)attrName);
+                 Object newAttrName = GetMyCDFData.replaceStringNameToXML ((Object)attrName);
                  try {
                    Entry entry = a.getEntry(v);
                    if (entry != null) {
@@ -1293,7 +1293,7 @@ Object newAttrName = GetMyCDFData.replaceStringNameToXML ((Object)attrName);
                  Attribute a = (Attribute) e.nextElement();
                  attrName = a.getName();
                  outputIndentation(indent);
-Object newAttrName = GetMyCDFData.replaceStringNameToXML ((Object)attrName);
+                 Object newAttrName = GetMyCDFData.replaceStringNameToXML ((Object)attrName);
                  if (mode.equalsIgnoreCase("cdfxdf")) {
                      out.println ("<parameter name=\""+newAttrName+"\">");
                      indent++;
@@ -1306,7 +1306,7 @@ Object newAttrName = GetMyCDFData.replaceStringNameToXML ((Object)attrName);
                      out.println ("</parameter> ");
                  }
                  else {
-out.println ("<attribute name=\""+newAttrName+"\"></attribute>");
+                   out.println ("<attribute name=\""+newAttrName+"\"></attribute>");
 /*
                    if (attrName.indexOf("\"") < 0)
                      out.println ("<attribute name=\""+attrName+"\"/>");
@@ -1490,9 +1490,9 @@ out.println ("<attribute name=\""+newAttrName+"\"></attribute>");
        System.out.println ("      With this \"-datatype\" option, the output will look as follows:");
        System.out.println ("        <record recNum=\"0\">");
        System.out.println ("           <array>");
-       System.out.println ("             <value xsi:type=\"sxd:short\">1</value>");
-       System.out.println ("             <value xsi:type=\"sxd:short\">2</value>");
-       System.out.println ("             <value xsi:type=\"sxd:short\">3</value>");
+       System.out.println ("             <value xsi:type=\"xsd:short\">1</value>");
+       System.out.println ("             <value xsi:type=\"xsd:short\">2</value>");
+       System.out.println ("             <value xsi:type=\"xsd:short\">3</value>");
        System.out.println ("           </array>");
        System.out.println ("        </record>");
        System.out.println ("");
