@@ -7,6 +7,7 @@
 import java.awt.*;
 import java.awt.event.*;
 import java.io.*;
+import java.nio.file.*;
 import java.util.*;
 import javax.swing.*;
 import java.awt.datatransfer.*;
@@ -19,6 +20,9 @@ public class CDFCompare extends JFrame
 				    MouseListener, FocusListener, Runnable  {
 
     static final long serialVersionUID = 1L;
+    static int macLib = 0;
+    static String cdfbase = null;
+    static String libcdfPath = null;
 
     JFrame parentDriver;
 /** The dialog for user interface. */
@@ -153,7 +157,7 @@ public class CDFCompare extends JFrame
     String currentdir = System.getProperty("user.dir");
 
 /** Environment variable for CDF_BASE. */
-    String cdfbase = System.getProperty("CDF_BASE");
+//    cdfbase = System.getProperty("CDF_BASE");
 
 /** The file separator. */
     String separator = System.getProperty("file.separator");
@@ -258,8 +262,16 @@ public class CDFCompare extends JFrame
     }
 
     CDFCompare(JFrame parentDriver, String basecdf, boolean modal) {
-        if (basecdf != null) command = "\"" + basecdf + separator + "bin" + 
-				       separator + "cdfcompare\" ";
+        if (cdfbase == null) {
+          cdfbase = System.getProperty("CDF_BASE");
+          if (cdfbase == null)
+            cdfbase = CDFToolsUtil.getenv("CDF_BASE");
+        }
+        if (cdfbase != null)
+          command = cdfbase + separator + "bin" + separator + "cdfcompare ";
+        else
+          command = "cdfcompare ";
+
 	dialog = new JDialog(this, modal);
         this.modal = modal;
 	this.parentDriver = parentDriver;
@@ -276,7 +288,10 @@ public class CDFCompare extends JFrame
                 if (modal) dialog.dispose();
                 else dialog.setVisible(false);
 		if (parentDriver != null) parentDriver.setVisible(true);
-              } else {System.exit(1);}
+              } else {
+		if (macLib == 1) new File(libcdfPath).delete();
+		System.exit(1);
+	      }
 	   }
         };
         dialog.addWindowListener(l);
@@ -544,7 +559,10 @@ public class CDFCompare extends JFrame
                 if (modal) dialog.dispose();
                 else dialog.setVisible(false);
 		if (parentDriver != null) parentDriver.setVisible(true);
-             } else {System.exit(1);}
+             } else {
+		if (macLib == 1) new File(libcdfPath).delete();
+		System.exit(1);
+	     }
 	} else if (obj == slt1 || obj == slt2 || obj == slt3) { // "Select 1|2|3" button
              if (obj == slt1) // "Select1" button for CDF1
                 doFileChooser("Select/enter the first CDF", cdf1, 1, cdffilter);
@@ -568,33 +586,6 @@ public class CDFCompare extends JFrame
                 runit(cmds);
                 // runit(commandX);
 		hlp = 0;
-            // try {
-            // Process proc = runtime.exec(commandX);
-            // put a BufferedReader on the ls output
-            // InputStream inputstream =
-            //     proc.getInputStream();
-            // InputStreamReader inputstreamreader =
-            //     new InputStreamReader(inputstream);
-            // BufferedReader bufferedreader =
-            //     new BufferedReader(inputstreamreader, 8192);
-            // read the ls output
-            // String line;
-            // while ((line = bufferedreader.readLine()) != null) {
-            //     System.out.println(line);
-            // }
-            // check for ls failure
-            // try {
-            //     if (proc.waitFor() != 0) {
-            //         System.err.println("exit value = " +
-            //             proc.exitValue());
-            //     }
-            // }
-            // } catch (Exception e) {
-            //       System.err.println(e);
-            // }
-
-
-
 	} else if (obj == entrb) { // for "Enter" button
                 cdfspec1 = cdf1.getText();
                 cdfspec2 = cdf2.getText();
@@ -933,45 +924,55 @@ public class CDFCompare extends JFrame
     private void runit(String[] command) {
     // private void runit(String command) {
         try {
-                if (command[1] != null)
+           String osName = System.getProperty("os.name");
+           String cwd = System.getProperty("user.dir");
+           libcdfPath = cwd + "/libcdf.dylib";
+           if (osName.toLowerCase().indexOf("mac") != -1) {
+               File libcdf = new File(libcdfPath);
+               if (libcdf.exists()) {
+                   macLib = 0;
+               } else {
+                 if (Files.isWritable(Paths.get(cwd))) {
+                   try {
+                     cdfbase = System.getProperty("CDF_BASE");
+                     if (cdfbase == null)
+                         cdfbase = CDFToolsUtil.getenv("CDF_BASE");
+                     Files.copy(Paths.get(cdfbase+"/lib/libcdf.dylib"),
+                                Paths.get(libcdfPath),
+                                StandardCopyOption.REPLACE_EXISTING);
+                     macLib = 1;
+                   } catch (Exception ex) {
+                     System.out.println ("**** Error for copying... "+ex);
+                   }
+                 }
+               }
+           }
+
+           if (command[1] != null)
                   process = runtime.exec(command);
-                else
+           else
                   process = runtime.exec(command[0]);
-/*
-                if (iba == 1 && hlp == 0 && abcX == 0) {
-                   info.setText("Program is submitted...\n\n");
-                   info.append("Compared results will be created in: " + 
-				filespec.trim());
-                } else {
-                  if (abcX == 0 && hlp == 0) {
-                    info.setText("");
-                    info.append("Program is running...\n");
-                  }
-*/
-                  Dimension dialogSize = dialog.getSize();
-                  ((JComponent)(dialog.getContentPane())).paintImmediately(
+           Dimension dialogSize = dialog.getSize();
+           ((JComponent)(dialog.getContentPane())).paintImmediately(
                                                 0, 0, dialogSize.width, dialogSize.height);
 
-                  BufferedReader inStream = new BufferedReader(new
-                                  InputStreamReader(process.getInputStream()), 8192);
+           InputStreamReader inReader = new InputStreamReader(process.getInputStream(), "UTF-8");
+           BufferedReader inStream = new BufferedReader(inReader, 8192);
 		  boolean first = true;
-                  String line = null;
-//		  if (hlp == 1 || abcX == 1 || ricX == 1 || rwcX == 1 || recX == 1 ||
-//                      lpcX == 1 || dscX == 1 || dlcX == 1 || dpcX == 1 || dvcX == 1) {
-                    while ((line = inStream.readLine()) != null) {
-		      if (first) {
+           String line = null;
+           while ((line = inStream.readLine()) != null) {
+		if (first) {
 			info.setText("");
 			first = false;
-		      }
+		}
                       info.append(line+"\n");
-		    }
-//		  }
-                  process.waitFor();
-		  info.setCaretPosition(0);
-                  if (process.exitValue() == 1) {
+	   }
+           process.waitFor();
+	   info.setCaretPosition(0);
+           if (process.exitValue() == 1) {
 		    Toolkit.getDefaultToolkit().beep();
 		    info.append("ERROR: error is detected... job failed\n");
-		  } 
+	   } 
         } catch (Exception e) {
                 info.setText("error executing: "+e);
                 Toolkit.getDefaultToolkit().beep();
@@ -983,9 +984,7 @@ public class CDFCompare extends JFrame
  */
 
     private void doFileChooser (String title, JTextField textField, int theone, SimpleFileFilter filter) {
-//        JFileChooser fileChooser = new JFileChooser();
 	ExampleFileView fileView = new ExampleFileView();
-//        fileChooser.setCurrentDirectory(new File(currentdir));
         fileChooser.setDialogTitle(title);
         if (filter != null) {
 	  fileChooser.addChoosableFileFilter(filter);
