@@ -479,8 +479,9 @@ public class CDFDir extends JFrame
               else
                 process = runtime.exec(command[0]);
 
-              BufferedReader inStream = new BufferedReader(new
-                                InputStreamReader(process.getInputStream()), 8192);
+              InputStreamReader inReader = new InputStreamReader(process.getInputStream(), "UTF-8");
+              BufferedReader inStream = new BufferedReader(inReader, 8192);
+
               String line = null;
               while ((line = inStream.readLine()) != null)
                 info.append(line+"\n");
