@@ -1045,8 +1045,9 @@ public class CDFExport extends JFrame implements ActionListener, ItemListener,
             try {
               Runtime runtime = Runtime.getRuntime();
               Process process = runtime.exec("cmd /c assoc .cdf");
-              BufferedReader inStream = new BufferedReader(new
-                                InputStreamReader(process.getInputStream()), 8192);
+              InputStreamReader inReader = new InputStreamReader(process.getInputStream(), "UTF-8");
+              BufferedReader inStream = new BufferedReader(inReader, 8192);
+
               try {
                 process.waitFor();
               } catch (InterruptedException ee) {
@@ -1056,8 +1057,8 @@ public class CDFExport extends JFrame implements ActionListener, ItemListener,
               if (thispgm.channelFile != null &&
                   thispgm.channelFile.toLowerCase().equals(".cdf=channelfile")) {
                 process = runtime.exec("cmd /c assoc .cdf="); // dis-associate it
-                inStream = new BufferedReader(new
-                                InputStreamReader(process.getInputStream()), 8192);
+                InputStreamReader inReader2 = new InputStreamReader(process.getInputStream(), "UTF-8");
+                inStream = new BufferedReader(inReader2, 8192);
 		String dummy = inStream.readLine(); // clear the input buffer
                 try {
                   process.waitFor();
