@@ -647,8 +647,9 @@ public class CDFIRsDump extends JFrame
               ((JComponent)(dialog.getContentPane())).paintImmediately(
                                                 0, 0, dialogSize.width, dialogSize.height);
               String line = null;
-              BufferedReader inStream = new BufferedReader(new
-                                      InputStreamReader(process.getInputStream()), 8192);
+              InputStreamReader inReader = new InputStreamReader(process.getInputStream(), "UTF-8");
+              BufferedReader inStream = new BufferedReader(inReader, 8192);
+
 	      info.setText("");
               while ((line = inStream.readLine()) != null)
                 info.append(line+"\n");
