@@ -7,6 +7,7 @@
 import java.awt.*;
 import java.awt.event.*;
 import java.io.*;
+import java.nio.file.*;
 import java.util.*;
 import javax.swing.*;
 import java.awt.datatransfer.*;
@@ -22,6 +23,9 @@ public class CDFStats extends JFrame
 				  MouseListener, FocusListener, Runnable {
 
     static final long serialVersionUID = 1L;
+    static int macLib = 0;
+    static String cdfbase = null;
+    static String libcdfPath = null;
 
     JFrame parentDriver;
 /** The dialog for user interface. */
@@ -228,8 +232,16 @@ public class CDFStats extends JFrame
     }
 
     CDFStats(JFrame parentDriver, String cdfbase, boolean modal) {
-        if (cdfbase != null) command = "\"" + cdfbase + separator + "bin" + 
-				       separator + "cdfstats\" ";
+        if (cdfbase == null) {
+          cdfbase = System.getProperty("CDF_BASE");
+          if (cdfbase == null)
+            cdfbase = CDFToolsUtil.getenv("CDF_BASE");
+        }
+        if (cdfbase != null)
+          command = cdfbase + separator + "bin" + separator + "cdfstats ";
+        else
+          command = "cdfstats ";
+
         dialog = new JDialog(this, modal);
 	this.parentDriver = parentDriver;
         this.modal = modal;
@@ -246,7 +258,10 @@ public class CDFStats extends JFrame
                 if (modal) dialog.dispose();
                 else dialog.setVisible(false);
 		if (parentDriver != null) parentDriver.setVisible(true);
-	      } else {System.exit(1);}
+	      } else {
+		if (macLib == 1) new File(libcdfPath).delete();
+		System.exit(1);
+	      }
 	   }
         };
         dialog.addWindowListener(l);
@@ -489,7 +504,10 @@ public class CDFStats extends JFrame
                 if (modal) dialog.dispose();
                 else dialog.setVisible(false);
 		if (parentDriver != null) parentDriver.setVisible(true);
-	     } else {System.exit(1);}
+	     } else {
+		if (macLib == 1) new File(libcdfPath).delete();
+		System.exit(1);
+	     }
 	}
 	else if (obj == slt1 || obj == slt2) { // for "Select 1|2" button
              if (obj == slt1) { // for "Select1" button
@@ -667,7 +685,7 @@ public class CDFStats extends JFrame
 		Toolkit.getDefaultToolkit().beep();
 		pgc.setSelected(false);
 	        strpo = "-nopage ";
-	 	}
+	   }
 	} else if (obj == abc) { // "About" checkbox
 	   if (abc.isSelected()) {
 		abcX = 1;
@@ -834,47 +852,54 @@ public class CDFStats extends JFrame
      private void runit(String[] command) {
 //    private void runit(String command) {
 	try {
-              if (command[1] != null) 
+           String osName = System.getProperty("os.name");
+           String cwd = System.getProperty("user.dir");
+           libcdfPath = cwd + "/libcdf.dylib";
+           if (osName.toLowerCase().indexOf("mac") != -1) {
+               File libcdf = new File(libcdfPath);
+               if (libcdf.exists()) {
+                   macLib = 0;
+               } else {
+                 if (Files.isWritable(Paths.get(cwd))) {
+                   try {
+                     cdfbase = System.getProperty("CDF_BASE");
+                     if (cdfbase == null)
+                         cdfbase = CDFToolsUtil.getenv("CDF_BASE");
+                     Files.copy(Paths.get(cdfbase+"/lib/libcdf.dylib"),
+                                Paths.get(libcdfPath),
+                                StandardCopyOption.REPLACE_EXISTING);
+                     macLib = 1;
+                   } catch (Exception ex) {
+                     System.out.println ("**** Error for copying... "+ex);
+                   }
+                 }
+               }
+           }
+           if (command[1] != null) 
                 process = runtime.exec(command);
-              else
+           else
                 process = runtime.exec(command[0]);
-/*
-              if (iba == 1 && hlp == 0 && abcX == 0) {
-                 info.setText("Program is submitted...\n\n");
-                 int idx = filespec.indexOf('.');
-		 info.append("A statistics file: " + filespec + 
-				(idx != -1 ? "" : ".sts") + " will/may be created.");
-              } else {
-                if (abcX == 0 && hlp == 0) {
-                   info.setText("");
-                   info.append("Program is running...\n");
-                }
-              }
-*/
-              Dimension dialogSize = dialog.getSize();
-              ((JComponent)(dialog.getContentPane())).paintImmediately(
+           Dimension dialogSize = dialog.getSize();
+           ((JComponent)(dialog.getContentPane())).paintImmediately(
                                               0, 0, dialogSize.width, dialogSize.height);
-              BufferedReader inStream = null;
-              String line = null;
-              inStream = new BufferedReader(new
-                                      InputStreamReader(process.getInputStream()), 8192);
-	      boolean first = true;	
-//              if (hlp == 1 || abcX == 1 || ricX == 1 || rwcX == 1 || recX == 1 ||
-//                    dscX == 1) {
-                while ((line = inStream.readLine()) != null) {
+           String line = null;
+           InputStreamReader inReader = new InputStreamReader(process.getInputStream(), "UTF-8");
+           BufferedReader inStream = new BufferedReader(inReader, 8192);
+
+	   boolean first = true;	
+           while ((line = inStream.readLine()) != null) {
 		    if (first) {
 			info.setText("");
 			first =false;
 		    }
                     info.append(line+"\n");
-		}
-//              }
-              process.waitFor();
-	      info.setCaretPosition(0);
-              if (process.exitValue() == 1) {
+	   }
+           process.waitFor();
+	   info.setCaretPosition(0);
+           if (process.exitValue() == 1) {
 		  Toolkit.getDefaultToolkit().beep();
 		  info.append("ERROR: error is detected... job failed\n");
-	      } else { 
+	   } else { 
                 scroller.getViewport().setView(info);
                 scroller.revalidate();
                 scroller.repaint();
@@ -886,7 +911,7 @@ public class CDFStats extends JFrame
 		       info.append("ERROR: check the statistics file for error information.");
 		     }
 		}
-              }
+           }
         } catch (Exception e) {
               info.setText("error executing: "+e);
 	      Toolkit.getDefaultToolkit().beep();
