@@ -48,7 +48,7 @@ public class CDFToolUtils implements CDFConstants {
 	    return aByte;
           } else {
             byte[] aByte = new byte[filterElementsNum];
-            for (int i = 0; i < filterElementsNum; i++) 
+            for (int i = 0; i < filterElementsNum; i++)
               aByte[i] = Byte.parseByte(((String)(vec.elementAt(i))).trim());
 	    return aByte;
           }
@@ -60,16 +60,18 @@ public class CDFToolUtils implements CDFConstants {
 		aShort = null;
 		throw new NumberFormatException(data);
 	      }
-	    }		
-	    return aShort;
+            }
+            return aShort;
           } else {
             short[] aShort = new short[filterElementsNum];
             for (int i = 0; i < filterElementsNum; i++) {
-              aShort[i] = Short.parseShort(((String)(vec.elementAt(i))).trim());
+              aShort[i] = Short.parseShort(((String)(vec.elementAt(i))).
+                                             trim());
               if (dataType == CDF_UINT1) {
                 if (aShort[i] < 0 || aShort[i] > 255) {
 		  aShort = null;
-		  throw new NumberFormatException(((String)(vec.elementAt(i))).trim());
+		  throw new NumberFormatException(((String)
+                                                   (vec.elementAt(i))).trim());
 		}
               }
 	    }
@@ -87,36 +89,38 @@ public class CDFToolUtils implements CDFConstants {
 	    return aInteger;
 	  } else {
 	    int[] aInteger = new int[filterElementsNum];
-	    for (int i = 0; i < filterElementsNum; i++) {
-	      aInteger[i] = Integer.parseInt(((String)(vec.elementAt(i))).trim());
-              if (dataType == CDF_UINT2) {
-                if (aInteger[i] < 0 || aInteger[i] > 65535) {
-		  aInteger = null;
-		  throw new NumberFormatException(((String)(vec.elementAt(i))).trim());
-		}
-              }
-	    }
-	    return aInteger;
+	      for (int i = 0; i < filterElementsNum; i++) {
+	        aInteger[i] = Integer.parseInt(((String)(vec.elementAt(i))).
+                                               trim());
+                if (dataType == CDF_UINT2) {
+                  if (aInteger[i] < 0 || aInteger[i] > 65535) {
+		    aInteger = null;
+		    throw new NumberFormatException(((String)
+                                                  (vec.elementAt(i))).trim());
+		  }
+                }
+	      }
+	      return aInteger;
 	  }
 	} else if (dataType == CDF_UINT4 || dataType == CDF_INT8) {
           if (filterElementsNum == 1) {
 	    long[] aLong = {Long.parseLong(data)};
             if (dataType == CDF_UINT4) {
-              if (aLong[0] < 0 || aLong[0] > 4294967285L) {
+              if (aLong[0] < 0 || aLong[0] > 4294967295L) {
 		aLong = null;
 		throw new NumberFormatException(data);
 	      }
             }
-
 	    return aLong;
           } else {
             long[] aLong = new long[filterElementsNum];
             for (int i = 0; i < filterElementsNum; i++) {
               aLong[i] = Long.parseLong(((String)(vec.elementAt(i))).trim());
               if (dataType == CDF_UINT4) {
-                if (aLong[i] < 0 || aLong[i] > 4294967285L) {
+                if (aLong[i] < 0 || aLong[i] > 4294967295L) {
 		  aLong = null;
-		  throw new NumberFormatException(((String)(vec.elementAt(i))).trim());
+		  throw new NumberFormatException(((String)
+                                                   (vec.elementAt(i))).trim());
 		}
               }
 	    }
@@ -129,7 +133,8 @@ public class CDFToolUtils implements CDFConstants {
           } else {
 	    float[] aFloat = new float[filterElementsNum];
             for (int i = 0; i < filterElementsNum; i++) 
-              aFloat[i] = Float.valueOf(((String)(vec.elementAt(i))).trim()).floatValue();
+              aFloat[i] = Float.valueOf(((String)(vec.elementAt(i))).trim()).
+                                          floatValue();
 	    return aFloat;
           }
 	} else if (dataType == CDF_REAL8 || dataType == CDF_DOUBLE) {
@@ -139,7 +144,8 @@ public class CDFToolUtils implements CDFConstants {
           } else {
             double[] aDouble = new double[filterElementsNum];
             for (int i = 0; i < filterElementsNum; i++) 
-              aDouble[i] = Double.valueOf(((String)(vec.elementAt(i))).trim()).doubleValue();
+              aDouble[i] = Double.valueOf(((String)(vec.elementAt(i))).
+                                            trim()).doubleValue();
 	    return aDouble;
           }
 	} else if (dataType == CDF_EPOCH) {
@@ -149,7 +155,7 @@ public class CDFToolUtils implements CDFConstants {
 	      if (data.indexOf(":") == -1) // not an EPOCH string
                 aDouble[0] = Double.valueOf(data).doubleValue();
 	      else
-	        aDouble[0] = Epoch.parse(data);
+	        aDouble[0] = Epoch.toParse(data);
               return aDouble;
             } else {
               double[] aDouble = new double[filterElementsNum];
@@ -158,7 +164,7 @@ public class CDFToolUtils implements CDFConstants {
 	        if (ttt.indexOf(":") == -1)
                   aDouble[i] = Double.valueOf(ttt).doubleValue();
 	        else
-	          aDouble[i] = Epoch.parse(ttt);
+	          aDouble[i] = Epoch.toParse(ttt);
 	      }	
               return aDouble;
             }
@@ -175,7 +181,7 @@ public class CDFToolUtils implements CDFConstants {
 		aDouble[1] = 0.0;
 	      }
               else
-                aDouble = (double[]) Epoch16.parse((String)data);
+                aDouble = (double[]) Epoch16.toParse((String)data);
               return aDouble;
             } else {
               double[][] aDouble = new double[filterElementsNum][2];
@@ -187,7 +193,7 @@ public class CDFToolUtils implements CDFConstants {
 		  aDouble[i][1] = 0.0;
 		}
                 else {
-		  aaa = (double[]) Epoch16.parse(ttt);
+		  aaa = (double[]) Epoch16.toParse(ttt);
                   aDouble[i][0] = aaa[0];
 		  aDouble[i][1] = aaa[1];
 		}
@@ -202,13 +208,13 @@ public class CDFToolUtils implements CDFConstants {
           try {
             if (filterElementsNum == 1) {
               long[] aLong = new long[1];
-              aLong[0] = (long) CDFTT2000.fromUTCstring((String)data);
+              aLong[0] = (long) CDFTT2000.toParse((String)data);
               return aLong;
             } else {
               long[] aLong = new long[filterElementsNum];
               for (int i = 0; i < filterElementsNum; i++) {
                 String ttt = ((String) vec.elementAt(i)).trim();
-		aLong[i] = (long) CDFTT2000.fromUTCstring(ttt);
+		aLong[i] = (long) CDFTT2000.toParse(ttt);
               }
               return aLong;
             }
@@ -224,7 +230,9 @@ public class CDFToolUtils implements CDFConstants {
  *  This method parses a string and returns an object based upon the data type
  */
 
-    public static Object parseContent (String data, long dataType, long numElems) throws CDFException, NumberFormatException {
+    public static Object parseContent (String data, long dataType,
+                                       long numElems)
+                         throws CDFException, NumberFormatException {
 
         data = data.trim();
         if (dataType == CDF_CHAR || dataType == CDF_UCHAR) {
@@ -237,7 +245,8 @@ public class CDFToolUtils implements CDFConstants {
                tmpString = data;
            else
              tmpString =  data;
-           if (tmpString.length() > numElems) throw new CDFException(BAD_NUM_ELEMS);
+           if (tmpString.length() > numElems) 
+             throw new CDFException(BAD_NUM_ELEMS);
            else return tmpString;
         } else 
 	   return CDFToolUtils.parseContent (data, dataType);
@@ -247,7 +256,8 @@ public class CDFToolUtils implements CDFConstants {
  *  This method parses a string and returns an object based upon the data type
  */
 
-    public static Object parseContent (String data, long dataType) throws NumberFormatException {
+    public static Object parseContent (String data, long dataType) 
+                         throws NumberFormatException {
 
         data = data.trim();
 
@@ -277,7 +287,7 @@ public class CDFToolUtils implements CDFConstants {
         } else if (dataType == CDF_UINT2 || dataType == CDF_INT4) {
             Integer aInteger = new Integer(data);
             if (dataType == CDF_UINT2) {
-              if (aInteger.shortValue() < 0 || aInteger.intValue() > 65535) {
+              if (aInteger.intValue() < 0 || aInteger.intValue() > 65535) {
 		aInteger = null;
 		throw new NumberFormatException(data);
 	      }
@@ -286,7 +296,7 @@ public class CDFToolUtils implements CDFConstants {
         } else if (dataType == CDF_UINT4 || dataType == CDF_INT8) {
             Long aLong = new Long(data);
             if (dataType == CDF_UINT4) {
-              if (aLong.shortValue() < 0 || aLong.longValue() > 4294967285L) {
+              if (aLong.longValue() < 0 || aLong.longValue() > 4294967295L) {
 		aLong = null;
 		throw new NumberFormatException(data);
 	      }
@@ -300,7 +310,7 @@ public class CDFToolUtils implements CDFConstants {
             return aDouble;
         } else if (dataType == CDF_EPOCH) {
 	  try {
-	    Double aDouble = new Double(Epoch.parse(data));
+	    Double aDouble = new Double(Epoch.toParse(data));
             return aDouble;
           } catch (CDFException e) {
             System.err.println("error parsing epoch ");
@@ -308,7 +318,7 @@ public class CDFToolUtils implements CDFConstants {
           }
         } else if (dataType == CDF_EPOCH16) {
           try {
-            double[] aDouble = (double[]) Epoch16.parse(data);
+            double[] aDouble = (double[]) Epoch16.toParse(data);
             return aDouble;
           } catch (CDFException e) {
             System.err.println("error parsing epoch16 ");
@@ -316,7 +326,7 @@ public class CDFToolUtils implements CDFConstants {
           }
         } else if (dataType == CDF_TIME_TT2000) {
 	  try {
-	    Long aLong = new Long(CDFTT2000.fromUTCstring(data));
+	    Long aLong = new Long(CDFTT2000.toParse(data));
             return aLong;
           } catch (CDFException e) {
             System.err.println("error parsing TT2000 ");
