@@ -158,18 +158,26 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
 	  String javaVersion = System.getProperty("java.version");
 	  int thisOS = new Integer(osVersion.substring(0, osVersion.indexOf("."))).intValue();
 	  int inIndex = javaVersion.indexOf(".");
-	  String subJavaVersion = javaVersion.substring(inIndex+1);
-	  int thisMajorV = new Integer(javaVersion.substring(0, inIndex)).intValue();
-	  int thisMinorV = new Integer(subJavaVersion.substring(0, subJavaVersion.indexOf("."))).intValue();
-	  int thisJava = (thisMinorV<10?thisMajorV*10+thisMinorV:thisMajorV*100+thisMinorV);
+          int thisMajorV, thisMinorV, thisJava;
+          if (inIndex != -1) {
+	    String subJavaVersion = javaVersion.substring(inIndex+1);
+	    thisMajorV = new Integer(javaVersion.substring(0, inIndex)).intValue();
+	    thisMinorV = new Integer(subJavaVersion.substring(0, subJavaVersion.indexOf("."))).intValue();
+	    thisJava = (thisMinorV<10?thisMajorV*10+thisMinorV:thisMajorV*100+thisMinorV);
+          } else {
+            /* Change like 17 to 170 */
+	    thisJava = new Integer(javaVersion).intValue()*10;
+          }
+            
 //        if (osVersion.compareTo("5.0") >= 0 &&   // Windows 2000 and beyond...
 //            javaVersion.compareTo("1.4") >= 0) { // Java 1.4
           if (thisOS >= 5 &&   // Windows 2000 and beyond...
                thisJava >= 14) { // Java 1.4
 	    try {
 	      process = runtime.exec("cmd /c assoc .cdf");
-	      inStream = new BufferedReader(new
-				InputStreamReader(process.getInputStream()), 8192);
+              InputStreamReader inReader1 = new InputStreamReader(process.getInputStream(), "UTF-8");
+              inStream = new BufferedReader(inReader1, 8192);
+
 	      try {
                 process.waitFor();
               } catch (InterruptedException ee) {
@@ -179,8 +187,9 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
               if (channelFile != null && 
 		  channelFile.toLowerCase().equals(".cdf=channelfile")) {
                 process = runtime.exec("cmd /c assoc .cdf="); // dis-associate it
-		inStream = new BufferedReader(new
-                                InputStreamReader(process.getInputStream()), 8192);
+                InputStreamReader inReader2 = new InputStreamReader(process.getInputStream(), "UTF-8");
+                inStream = new BufferedReader(inReader2, 8192);
+
 		String dummy = inStream.readLine(); // clear the input buffer
                 try {
                   process.waitFor();
@@ -190,8 +199,9 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
 	        }
 	      }
               process = Runtime.getRuntime().exec("cmd /c echo %CDF_BASE%");
-              inStream = new BufferedReader
-                   ( new InputStreamReader( process.getInputStream() ) );
+              InputStreamReader inReader3 = new InputStreamReader(process.getInputStream(), "UTF-8");
+              inStream = new BufferedReader(inReader3, 8192);
+
               try {
                 process.waitFor();
               } catch (InterruptedException ee) {
@@ -215,8 +225,9 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
             try {
                String line;
                process = runtime.exec("env"); // Use "env" instead of "printenv"
-               inStream = new BufferedReader(new
-                                  InputStreamReader(process.getInputStream()));
+               InputStreamReader inReader4 = new InputStreamReader(process.getInputStream(), "UTF-8");
+               inStream = new BufferedReader(inReader4, 8192);
+
                process.waitFor();
                while ((line = inStream.readLine()) != null) {
                  StringTokenizer st = new StringTokenizer(line, "=");
@@ -697,8 +708,9 @@ public class CDFToolsDriver extends JFrame implements ActionListener {
 	  Process process = runtime.exec(cmd);
           BufferedReader inStream = null;
           String line = null;
-          inStream = new BufferedReader(new
-                     InputStreamReader(process.getInputStream()), 8192);
+          InputStreamReader inReader5 = new InputStreamReader(process.getInputStream(), "UTF-8");
+          inStream = new BufferedReader(inReader5, 8192);
+
           line = inStream.readLine();
           process.waitFor();
 	  int ix=line.indexOf("x86-64");
