@@ -34,16 +34,17 @@ public class CDFToolsUtil {
           if (OS.indexOf("windows") != -1) {
               String command = "cmd /c echo %" + envVar + "%";
               process = Runtime.getRuntime().exec(command);
-              inStream = new BufferedReader
-                              ( new InputStreamReader(process.getInputStream()) );
+              InputStreamReader inReader = new InputStreamReader(process.getInputStream(), "UTF-8");
+              inStream = new BufferedReader(inReader, 8192);
+
               process.waitFor();
               value = inStream.readLine();
           }
           else if (OS.indexOf("vms") == -1) {     /* not VMS = Unix */
               process = Runtime.getRuntime().exec("env");
 
-              inStream = new BufferedReader(new
-                                 InputStreamReader(process.getInputStream()));
+              InputStreamReader inReader2 = new InputStreamReader(process.getInputStream(), "UTF-8");
+              inStream = new BufferedReader(inReader2, 8192);
               process.waitFor();
               while ((line = inStream.readLine()) != null) {
                  StringTokenizer st = new StringTokenizer(line, "=");
