@@ -17,8 +17,9 @@ public class CheckJVM {
 	  Process process = runtime.exec(cmd);
           BufferedReader inStream = null;
           String line = null;
-          inStream = new BufferedReader(new
-                     InputStreamReader(process.getInputStream()), 8192);
+          InputStreamReader inReader2 = new InputStreamReader(process.getInputStream(), "UTF-8");
+          inStream = new BufferedReader(inReader2, 8192);
+
           line = inStream.readLine();
           process.waitFor();
 	  System.err.println("output\t ==>\t "+line);
