@@ -1,4 +1,4 @@
-// $Id: EditAttrEntryDialog.java,v 1.1.1.1 2022/04/01 12:25:56 mhliu Exp $
+// $Id: EditAttrEntryDialog.java,v 1.1.1.1 2023/08/01 12:28:28 mhliu Exp $
 /******************************************************************************
 * Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
@@ -192,21 +192,22 @@ public class EditAttrEntryDialog extends JDialog implements CDFConstants, Action
     public static void editEntry(EditAttrEntryPanel myPanel, String title) {
     
 	if (cache == null) cache = new EditAttrEntryDialog(myPanel);
-					    
-	cache.myPanel = myPanel;
-	cache.scope = myPanel.getScope();
-        cache.entry = myPanel.getSelectedEntry();
-        cache.dataType = cache.entry.getDataType();
-        cache.numElements = cache.entry.getNumElements();
 
-        if (cache.scope == GLOBAL_SCOPE) {
-          cache.tfen.setMaxLength(3);
-	  cache.tfen.setLabel("Entry Number");
-        } else {
-          cache.tfen.setMaxLength(30); 
-          cache.tfen.setLabel("Variable Name");
-        }
+	try {				    
+	  cache.myPanel = myPanel;
+	  cache.scope = myPanel.getScope();
+          cache.entry = myPanel.getSelectedEntry();
+          cache.dataType = cache.entry.getDataType();
+          cache.numElements = cache.entry.getNumElements();
 
+          if (cache.scope == GLOBAL_SCOPE) {
+            cache.tfen.setMaxLength(3);
+	    cache.tfen.setLabel("Entry Number");
+          } else {
+            cache.tfen.setMaxLength(30); 
+            cache.tfen.setLabel("Variable Name");
+          }
+        } catch (Exception ex) { }
 	cache.reset();
 	cache.setTitle(title);
 	cache.setVisible(true);
