@@ -1,4 +1,4 @@
-// $Id: EditAttrEntryPanel.java,v 1.1.1.1 2022/04/01 12:25:56 mhliu Exp $
+// $Id: EditAttrEntryPanel.java,v 1.1.1.1 2023/08/01 12:28:28 mhliu Exp $
 /******************************************************************************
 * Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
@@ -184,12 +184,12 @@ public class EditAttrEntryPanel extends JDialog
 	mi.setToolTipText("Create a new attribute entry");
         mi.setMnemonic('N');
 	if (scope == GLOBAL_SCOPE) mi.setEnabled(true);
-	else mi.setEnabled(false);
+	else mi.setEnabled(true);
 
         mi = (JMenuItem) entryMenu.add(new DeleteEntryAction( this ));
 	mi.setToolTipText("Delete the selected attribute entry");
         mi.setMnemonic('D');
-        mi.setEnabled(false);
+        mi.setEnabled(true);
 
         entryMenu.add(new JSeparator());
 
@@ -198,7 +198,7 @@ public class EditAttrEntryPanel extends JDialog
         mi = (JMenuItem) entryMenu.add(editAttrEntry);
 	mi.setToolTipText("Modify the selected attribute entry");
 	mi.setMnemonic('M');
-        mi.setEnabled(false);
+        mi.setEnabled(true);
 
         entryMenu.add(new JSeparator());
 
