@@ -201,10 +201,10 @@ public class EditvAttributeTableScrollPane extends JScrollPane implements TableM
         public boolean isCellEditable(int row, int col) {
             //Note that the data/cell address is constant,
             //no matter where the cell appears onscreen.
-            if (col == 0)
+            if (col < 2)
                 return false;
             else
-		return false;
+		return true;
         }
 
         /*
@@ -224,102 +224,37 @@ public class EditvAttributeTableScrollPane extends JScrollPane implements TableM
         public void setValueAt(Object value, int row, int col) {
 
             Object oldone = getValueAt(row, col);
-
-            if (dataObject[0][col] instanceof Integer) {
-                //If we don't do something like this, the column
-                //switches to contain Strings.
-                //XXX: See TableEditDemo.java for a better solution!!!
-                try {
-                    if (col == 1) applyValue(oldone, value, row, col);
-                    if (col == 2) value = checkValue(value, row);
-                    dataObject[row][col] = new Integer((String)value);
-                    fireTableCellUpdated(row, col);
-                } catch (NumberFormatException e) {
-		    Toolkit.getDefaultToolkit().beep();
-                    JOptionPane.showMessageDialog(myEditor.frame,
-                        "The \"" + getColumnName(col)
-                        + "\" column accepts only integer values.");
-                }
-            } else if (dataObject[0][col] instanceof Float) {
-                try {
-                    if (col == 1) applyValue(oldone, value, row, col);
-                    if (col == 2) value = checkValue(value, row);
-                    dataObject[row][col] = new Float((String)value);
-                    fireTableCellUpdated(row, col);
-                } catch (NumberFormatException e) {
-		    Toolkit.getDefaultToolkit().beep();
-                    JOptionPane.showMessageDialog(myEditor.frame,
-                        "The \"" + getColumnName(col)
-                        + "\" column accepts only float values.");
-                }
-            } else if (dataObject[0][col] instanceof Byte) {
-                try {
-                    if (col == 1) applyValue(oldone, value, row, col);
-                    if (col == 2) value = checkValue(value, row);
-                    dataObject[row][col] = new Byte((String)value);
-                    fireTableCellUpdated(row, col);
-                } catch (NumberFormatException e) {
-		    Toolkit.getDefaultToolkit().beep();
-                    JOptionPane.showMessageDialog(myEditor.frame,
-                        "The \"" + getColumnName(col)
-                        + "\" column accepts only yyte values.");
-                }
-            } else if (dataObject[0][col] instanceof Long) {
-                try {
-                    if (col == 1) applyValue(oldone, value, row, col);
-                    if (col == 2) value = checkValue(value, row);
-                    dataObject[row][col] = new Long((String)value);
-                    fireTableCellUpdated(row, col);
-                } catch (NumberFormatException e) {
-		    Toolkit.getDefaultToolkit().beep();
-                    JOptionPane.showMessageDialog(myEditor.frame,
-                        "The \"" + getColumnName(col)
-                        + "\" column accepts only long values.");
-                }
-            } else if (dataObject[0][col] instanceof Short) {
-                try {
-                    if (col == 1) applyValue(oldone, value, row, col);
-                    if (col == 2) value = checkValue(value, row);
-                    dataObject[row][col] = new Short((String)value);
-                    fireTableCellUpdated(row, col);
-                } catch (NumberFormatException e) {
-		    Toolkit.getDefaultToolkit().beep();
-                    JOptionPane.showMessageDialog(myEditor.frame,
-                        "The \"" + getColumnName(col)
-                        + "\" column accepts only short values.");
-                }
-            } else if (dataObject[0][col] instanceof Double) {
-                try {
-                    if (col == 1) applyValue(oldone, value, row, col);
-                    if (col == 2) value = checkValue(value, row);
-                    dataObject[row][col] = new Double((String)value);
-                    fireTableCellUpdated(row, col);
-                } catch (NumberFormatException e) {
-		    Toolkit.getDefaultToolkit().beep();
-                    JOptionPane.showMessageDialog(myEditor.frame,
-                        "The \"" + getColumnName(col)
-                        + "\" column accepts only double values.");
-                }
-            } else if (dataObject[0][col] instanceof Boolean) {
-                try {
-                    if (col == 1) applyValue(oldone, value, row, col);
-                    if (col == 2) value = checkValue(value, row);
-                    dataObject[row][col] = (Boolean)value;
-                    fireTableCellUpdated(row, col);
-                } catch (NumberFormatException e) {
-		    Toolkit.getDefaultToolkit().beep();
-                    JOptionPane.showMessageDialog(myEditor.frame,
-                        "The \"" + getColumnName(col)
-                        + "\" column accepts only boolean values.");
-                }
-
+            dataObject[row][col] = value;
+            fireTableCellUpdated(row, col);
+            String varName = (String) getValueAt(row, 0);
+            String dataTypeStr = (String) getValueAt(row, 1);
+            int index = dataTypeStr.indexOf("/");
+            String forDataType = dataTypeStr.substring(0, index);
+            String forElems = dataTypeStr.substring(index+1);
+            int numElemsx, isChar;
+            long dataTypeNum = CDFUtils.getDataTypeValue(forDataType);
+            Object value2 = null;
+            if (dataTypeStr.indexOf("CHAR") != -1) {
+              isChar = 1;
+              numElemsx = ((String)value).length();
             } else {
-                if (col == 1) applyValue(oldone, value, row, col);
-                if (col == 2) value = checkValue(value, row);
-                dataObject[row][col] = value;
-                fireTableCellUpdated(row, col);
+              String[] tokens = ((String)value).split(",");
+              numElemsx = tokens.length;
+              isChar = 0;
+              value2 = CDFToolUtils.parseContents ((String)value, dataTypeNum);
+            }
+            String newDataType = new StringBuffer(forDataType).append("/").
+                                                  append(numElemsx).toString();
+            dataObject[row][1] = newDataType;
+            fireTableCellUpdated(row, 1);
+            try {
+              long entryID = cdf.getVariableID(varName);
+              attr.deleteEntry(entryID);
+              Entry.create(attr, entryID, dataTypeNum, (isChar==1?value:value2));
+            } catch (Exception ex) {
+              JOptionPane.showMessageDialog(myEditor.frame,
+                                               "The change failed... "+ex);
             }
-
         }
 
         void applyValue(Object origin, Object newone, int row, int col) {
@@ -332,89 +267,6 @@ public class EditvAttributeTableScrollPane extends JScrollPane implements TableM
             }
         }
 
-        void checkNumElem(Object newone, int row) {
-            String dataType = (String) getValueAt(row, 1);
-            if (dataType.equals("CDF_CHAR") && dataType.equals("CDF_UCHAR"))
-              dataObject[row][2] = "" + ((String)newone).length();
-            else
-              dataObject[row][2] = "1";
-            fireTableCellUpdated(row, 2);
-        }
-
-        Object checkValue(Object newone, int row) {
-
-            String dataType = (String) getValueAt(row, 1);
-            NumberFormat formatter = NumberFormat.getNumberInstance();
-            if (dataType.equals("CDF_BYTE") || dataType.equals("CDF_INT1")) {
-                formatter.setParseIntegerOnly(true);
-                try {
-                  if (newone instanceof Byte)
-                    return new Byte(formatter.parse(((Byte)newone).toString()).byteValue());
-                  else
-                    return (String) "" + formatter.parse((String)newone).byteValue();
-                } catch (ParseException e) {
-                  return null;
-                }
-            } else if (dataType.equals("CDF_UINT1") || dataType.equals("CDF_INT2")) {
-
-                formatter.setParseIntegerOnly(true);
-                try {
-                  if (newone instanceof Short)
-                    return new Short(formatter.parse(((Short)newone).toString()).shortValue());
-                  else
-                    return (String) "" + formatter.parse((String)newone).shortValue();
-                } catch (ParseException e) {
-                  return null;
-                }
-            } else if (dataType.equals("CDF_UINT2") || dataType.equals("CDF_INT4")) {
-
-                formatter.setParseIntegerOnly(true);
-                try {
-                  if (newone instanceof Integer)
-                    return new Integer(formatter.parse(((Integer)newone).toString()).intValue());
-                  else
-                    return (String) "" + formatter.parse((String)newone).intValue();
-                } catch (ParseException e) {
-                  return null;
-                }
-            } else if (dataType.equals("CDF_UINT4") || dataType.equals("CDF_INT8")) {
-
-                formatter.setParseIntegerOnly(true);
-                try {
-                  if (newone instanceof Long)
-                    return new Long(formatter.parse(((Long)newone).toString()).longValue());
-                  else
-                    return (String) "" + formatter.parse((String)newone).longValue();
-                } catch (ParseException e) {
-                  return null;
-                }
-            } else if (dataType.equals("CDF_REAL4") || dataType.equals("CDF_FLOAT")) {
-                formatter.setParseIntegerOnly(false);
-                try {
-                  if (newone instanceof Float)
-                    return new Float(formatter.parse(((Float)newone).toString()).floatValue());
-                  else
-                    return (String) "" + formatter.parse((String)newone).floatValue();
-                } catch (ParseException e) {
-                  return null;
-                }
-            } else if (dataType.equals("CDF_REAL8") || dataType.equals("CDF_EPOCH")) {
-
-                formatter.setParseIntegerOnly(false);
-                try {
-                  if (newone instanceof Double)
-                    return new Double(formatter.parse(((Double)newone).toString()).doubleValue());
-                  else
-                    return (String) "" + formatter.parse((String)newone).doubleValue();
-                } catch (ParseException e) {
-                  return null;
-                }
-            } else if (dataType.equals("CDF_CHAR") || dataType.equals("CDF_UCHAR")) {
-                return newone;
-            }
-            return null;
-        }
-
     }
 
 /**
