@@ -7,6 +7,7 @@
 import java.awt.*;
 import java.awt.event.*;
 import java.io.*;
+import java.nio.file.*;
 import java.util.*;
 import javax.swing.*; 
 import java.awt.datatransfer.*;
@@ -21,6 +22,9 @@ public class SkeletonTable extends JFrame
 				       MouseListener, FocusListener, Runnable { 
 
     static final long serialVersionUID = 1L;
+    static int macLib = 0;
+    static String cdfbase = null;
+    static String libcdfPath = null;
 
     JFrame parentDriver;
 /** The dialog for user interface. */
@@ -280,8 +284,16 @@ public class SkeletonTable extends JFrame
     }
 
     SkeletonTable(JFrame parentDriver, String cdfbase, boolean modal) {
-        if (cdfbase != null) command = "\"" + cdfbase + separator + "bin" + 
-				       separator + "skeletontable\" ";
+        if (cdfbase == null) {
+          cdfbase = System.getProperty("CDF_BASE");
+          if (cdfbase == null)
+            cdfbase = CDFToolsUtil.getenv("CDF_BASE");
+        }
+        if (cdfbase != null)
+          command = cdfbase + separator + "bin" + separator + "skeletontable ";
+        else
+          command = "skeletontable ";
+
 	dialog = new JDialog(this, modal);
 	this.parentDriver = parentDriver;
 	this.modal = modal;
@@ -316,11 +328,14 @@ public class SkeletonTable extends JFrame
 
         WindowListener l = new WindowAdapter() {
            public void windowClosing(WindowEvent e) {
+	      if (macLib == 1) new File(libcdfPath).delete();
               if (frommain == 0) {
 		if (modal) dialog.dispose();
 		else dialog.setVisible(false);
 		if (parentDriver != null) parentDriver.setVisible(true);
-              } else {System.exit(1);}
+              } else {
+		System.exit(1);
+	      }
 	   }
         };
         dialog.addWindowListener(l);
@@ -665,11 +680,14 @@ public class SkeletonTable extends JFrame
 	Object obj = evt.getSource();
 	info.setText("");
 	if (obj == quitb || obj == menuFileExit) { // for "Quit" or "Exit"
+	     if (macLib == 1) new File(libcdfPath).delete();
              if (frommain == 0) {
 		if (modal) dialog.dispose();
 		else dialog.setVisible(false);
 		if (parentDriver != null) parentDriver.setVisible(true);
-             } else {System.exit(1);}
+             } else {
+		System.exit(1);
+	     }
 	} else if (obj == slt1 || obj == slt2) { // for "Select 1|2" button
              if (obj == slt1) { // for "Select1" button
 		doFileChooser("Select/enter a cdf", cdf, 1, filter1);
@@ -1069,9 +1087,33 @@ public class SkeletonTable extends JFrame
     private void runit(String[] command) {
     // private void runit(String command) {
 	try {
-                if (command[1] != null)
+           String osName = System.getProperty("os.name");
+           String cwd = System.getProperty("user.dir");
+           libcdfPath = cwd + "/libcdf.dylib";
+           if (osName.toLowerCase().indexOf("mac") != -1) {
+               File libcdf = new File(libcdfPath);
+               if (libcdf.exists()) {
+                   macLib = 0;
+               } else {
+                 if (Files.isWritable(Paths.get(cwd))) {
+                   try {
+                     cdfbase = System.getProperty("CDF_BASE");
+                     if (cdfbase == null)
+                         cdfbase = CDFToolsUtil.getenv("CDF_BASE");
+                     Files.copy(Paths.get(cdfbase+"/lib/libcdf.dylib"),
+                                Paths.get(libcdfPath),
+                                StandardCopyOption.REPLACE_EXISTING);
+                     macLib = 1;
+                   } catch (Exception ex) {
+                     System.out.println ("**** Error for copying... "+ex);
+                   }
+                 }
+               }
+           }
+
+           if (command[1] != null)
                   process = runtime.exec(command);
-                else
+           else
                   process = runtime.exec(command[0]);
 /*
                 if (iba == 1 && hlp == 0 && abcX == 0) {
@@ -1090,35 +1132,36 @@ public class SkeletonTable extends JFrame
                           info.setText("Program is running...\n");
                   }
 */
-		  Dimension dialogSize = dialog.getSize();
-		  ((JComponent)(dialog.getContentPane())).paintImmediately(
+	   Dimension dialogSize = dialog.getSize();
+	   ((JComponent)(dialog.getContentPane())).paintImmediately(
   						0, 0, dialogSize.width, dialogSize.height);
-		  String line = null;
-		  boolean first = true;
-                  BufferedReader inStream = new BufferedReader(new 
-				      InputStreamReader(process.getInputStream()), 8192);
-		  if (hlp == 1 || abcX == 1 || ricX == 1 || rwcX == 1 || recX == 1 ||
-		      lpcX == 1 || dscX == 1 || oscX == 1) {
-                    while ((line = inStream.readLine()) != null) {
-		      if (first) {
+	   String line = null;
+	   boolean first = true;
+           InputStreamReader inReader2 = new InputStreamReader(process.getInputStream(), "UTF-8");
+           BufferedReader inStream = new BufferedReader(inReader2, 8192);
+
+	   if (hlp == 1 || abcX == 1 || ricX == 1 || rwcX == 1 || recX == 1 ||
+	       lpcX == 1 || dscX == 1 || oscX == 1) {
+               while ((line = inStream.readLine()) != null) {
+		   if (first) {
 			info.setText("");
 			first = false;
-		      }
-                      info.append(line+"\n");
-		    }
-		  }
-                  process.waitFor();
-		  info.setCaretPosition(0);
-		  if (process.exitValue() == 1) 
+		   }
+                   info.append(line+"\n");
+	       }
+	   }
+           process.waitFor();
+	   info.setCaretPosition(0);
+	   if (process.exitValue() == 1) 
 		    Toolkit.getDefaultToolkit().beep();
-                  else {
-		    if (iba == 1) {
-			if (info.getText().toLowerCase().indexOf("error") == -1)
-			  info.append("Done!\n\n");
-			else 
-			  info.append("ERROR: skeleton table is invalid.\n");
-		    }
-		  } 
+           else {
+		if (iba == 1) {
+		   if (info.getText().toLowerCase().indexOf("error") == -1)
+			info.append("Done!\n\n");
+		   else 
+			info.append("ERROR: skeleton table is invalid.\n");
+		}
+	   } 
 	} catch (Exception e) {
                 info.setText("error executing: "+e);
                 Toolkit.getDefaultToolkit().beep();
