@@ -267,6 +267,9 @@ public class CDFException
                  "The blocking factor set for the compressed variable is smaller than the default. It is changed but may make data access ineffective.");
         msgs.put(new Long(BLOCKINGFACTOR_TOO_SMALL2), "BLOCKINGFACTOR_TOO_SMALL2: " +
                  "The variable's blocking factor is smaller than the default if it is compressed. The compression is set but may make data access ineffective.");
+        msgs.put(new Long(BLOCKINGFACTOR_TOO_LARGE), "BLOCKINGFACTOR_TOO_LaRGE: " +
+                 "The intended blocking factor is too large. To avoid a "+
+"temporary file(s) to be created for compression, a smaller value is assigned.");
         msgs.put(new Long(TRY_TO_READ_NONSTRING_DATA), "TRY_TO_READ_NONSTRING_DATA: " +
                  "Wrong function as the attribute entry data is non-string.");
         msgs.put(new Long(BAD_NUM_STRINGS), "BAD_NUM_STRINGS: " +
