@@ -1,4 +1,4 @@
-// $Id: CDFUtils.java,v 1.2 2023/01/09 18:24:21 mhliu Exp $
+// $Id: CDFUtils.java,v 1.2 2024/11/05 12:34:56 mhliu Exp $
 /*
  * Copyright 1996-2014 United States Government as represented by the
  * Administrator of the National Aeronautics and Space Administration.
@@ -327,9 +327,17 @@ public class CDFUtils implements CDFConstants {
             else if (which == 3)
               System.out.println (CDFTT2000.encode(((Long)data).longValue())+addZ);
             else {
-              if (data instanceof String)
-                System.out.println ("\""+data+"\"");
-              else
+              if (data instanceof String) {
+		int len = ((String)data).length();
+		if (len == 1) {
+		  byte[] bytes = ((String)data).getBytes(); 
+		  if (bytes[0] == 0)
+                    System.out.println ("\"\"");
+		  else
+		    System.out.println ("\""+data+"\"");
+		} else
+                  System.out.println ("\""+data+"\"");
+              } else
                 System.out.println (data);
             }
 	  }
@@ -353,6 +361,27 @@ public class CDFUtils implements CDFConstants {
         CDFUtils.printData (data, which, true);
     }
 
+    /**
+     *  Prints the value of the given data on the screen.  Data can be a
+     *  java primitive data type, Java Object (non-array), or
+     *  1-dimensional array of primitive Java data type.
+     *
+     *  @param data the data to be printed
+     *  @param dataType the CDF data type of the data
+     *
+     */
+    public static void printData (Object data, long dataType) {
+
+	if (dataType == CDF_EPOCH)
+          CDFUtils.printData (data, 1);
+	else if (dataType == CDF_EPOCH16)
+          CDFUtils.printData (data, 2);
+	else if (dataType == CDF_TIME_TT2000)
+          CDFUtils.printData (data, 3);
+	else
+          CDFUtils.printData (data, 0);
+    }
+
     /**
      *  Prints the value of the given data to the place designated by
      *  PrintWriter that can be a file, Sysem.out, System.err, and etc.  
@@ -493,7 +522,6 @@ public class CDFUtils implements CDFConstants {
              outWriter.print (CDFTT2000.encode(((Long)data).longValue())+addZ);
            else
 	     outWriter.print (data);
-
 	}
     }
 
@@ -1419,16 +1447,19 @@ public class CDFUtils implements CDFConstants {
      *          <UL>
      *             <LI>NONE
      *             <LI>RLE
-     *             <LI>Huffman
-     *             <LI>Adaptive Huffman
+     *             <LI>HUFF (as Huffman)
+     *             <LI>AHUFF (as Adaptive Huffman)
      *             <LI>GZIP
      *             <LI>UNKNOWN (for unknown compressionType)
      *          </UL>
      */
     public static String getStringCompressionType (long compressionType) {
-
+/*
         String cDataTypes[] = {"NONE",   "RLE", "Huffman",
                                "Adaptive Huffman", " ",   "GZIP"};
+*/
+        String cDataTypes[] = {"NONE",   "RLE", "HUFF",
+                               "AHUFF",  " ",   "GZIP"};
 
         // RICE (4) is no longer supported.
         if ((compressionType > GZIP_COMPRESSION) || (compressionType == 4L))
@@ -1446,8 +1477,8 @@ public class CDFUtils implements CDFConstants {
      *          <UL>
      *             <LI>NONE
      *             <LI>RLE
-     *             <LI>Huffman
-     *             <LI>Adaptive Huffman
+     *             <LI>HUFF (as Huffman)
+     *             <LI>AHUFF (as Adaptive Huffman)
      *             <LI>GZIP
      *          </UL><P>
      *
@@ -1464,9 +1495,12 @@ public class CDFUtils implements CDFConstants {
      */
 
     public static long getLongCompressionType (String compressionType) {
-
+/*
         String cDataTypes[] = {"NONE",   "RLE", "Huffman",
                                "Adaptive Huffman", " ",   "GZIP"};
+*/
+        String cDataTypes[] = {"NONE",   "RLE", "HUFF",
+                               "Ahuff",  " ",   "GZIP"};
 
         // RICE (4) is no longer supported.
 	int i;
